import React, { useEffect, useState } from 'react';
import DewarDetails from './DewarDetails.tsx';
import { Shipment, ContactPerson, Address, Dewar } from '../types.ts';
import shipmentData from '../../public/shipmentsdb.json'; // Adjust the path to where your JSON file is stored

const ParentComponent = () => {
    const [dewars, setDewars] = useState<Dewar[]>([]);
    const [contactPersons, setContactPersons] = useState<ContactPerson[]>([]);
    const [returnAddresses, setReturnAddresses] = useState<Address[]>([]);
    const [selectedShipment, setSelectedShipment] = useState<Shipment | null>(null);

    useEffect(() => {
        const firstShipment = shipmentData.shipments[0] as Shipment; // Ensure proper typing
        setSelectedShipment(firstShipment);
        setContactPersons(firstShipment.contact_person || []); // Set to array directly
        if (firstShipment.return_address) {
            setReturnAddresses(firstShipment.return_address); // Set to array directly
        }

        const dewarsWithId = firstShipment.dewars.map((dewar, index) => ({
            ...dewar,
            id: `${firstShipment.shipment_id}-Dewar-${index + 1}`,
        }));

        setDewars(dewarsWithId);
    }, []);

    const addNewContactPerson = (name: string) => {
        const newContact: ContactPerson = { id: `${contactPersons.length + 1}`, name };
        setContactPersons((prev) => [...prev, newContact]);
    };

    const addNewReturnAddress = (address: string) => {
        const newAddress: Address = { id: `${returnAddresses.length + 1}`, address };
        setReturnAddresses((prev) => [...prev, newAddress]);
    };

    const selectedDewar = dewars[0]; // Just picking the first dewar for demonstration

    return (
        <DewarDetails
            dewar={selectedDewar}
            trackingNumber={''}
            setTrackingNumber={() => {}}
            onGenerateQRCode={() => {}}
            contactPersons={contactPersons}
            returnAddresses={returnAddresses}
            addNewContactPerson={addNewContactPerson}
            addNewReturnAddress={addNewReturnAddress}
        />
    );
};

export default ParentComponent;