import React from 'react';
import { Grid } from '@mui/material';
import ShipmentPanel from './ShipmentPanel.tsx';
import ShipmentDetails from './ShipmentDetails.tsx';
import ShipmentForm from './ShipmentForm.tsx';
import { Shipment, Dewar } from '../types.ts';
import { ContactPerson, Address, Proposal } from '../types.ts';

interface ShipmentProps {
    newShipment: Shipment;
    setNewShipment: React.Dispatch<React.SetStateAction<Shipment>>;
    isCreatingShipment: boolean;
    setIsCreatingShipment: React.Dispatch<React.SetStateAction<boolean>>;
    selectedShipment: Shipment | null;
    selectShipment: (shipment: Shipment | null) => void; // Allow null for deselection
    selectedDewar: Dewar | null;
    setSelectedDewar: React.Dispatch<React.SetStateAction<Dewar | null>>;
    handleSaveShipment: () => void;
    contactPersons: ContactPerson[];
    returnAddresses: Address[];
    proposals: Proposal[];
}

const ShipmentView: React.FC<ShipmentProps> = ({
                                                   newShipment,
                                                   setNewShipment,
                                                   isCreatingShipment,
                                                   setIsCreatingShipment,
                                                   selectedShipment,
                                                   selectShipment,
                                                   selectedDewar,
                                                   setSelectedDewar,
                                                   handleSaveShipment,
                                                   contactPersons,
                                                   returnAddresses,
                                                   proposals,
                                               }) => {
    return (
        <Grid container spacing={2} sx={{ height: '100vh' }}>
            {/* Left column: ShipmentPanel */}
            <Grid
                item
                xs={12}
                md={3} // Adjust width for left column
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 0, // Do not allow the panel to grow
                }}
            >
                <ShipmentPanel
                    selectedPage="Shipments"
                    setIsCreatingShipment={setIsCreatingShipment}
                    newShipment={newShipment}
                    setNewShipment={setNewShipment}
                    selectShipment={selectShipment} // This now accepts Shipment | null
                />
            </Grid>

            {/* Right column: ShipmentForm or ShipmentDetails */}
            <Grid
                item
                xs={12}
                md={9}
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 1,
                }}
            >
                {isCreatingShipment ? (
                    <ShipmentForm
                        newShipment={newShipment}
                        setNewShipment={setNewShipment}
                        handleSaveShipment={handleSaveShipment}
                        contactPersons={contactPersons}
                        proposals={proposals}
                        returnAddresses={returnAddresses}
                        sx={{ flexGrow: 1 }} // Allow form to grow and take available space
                    />
                ) : (
                    <ShipmentDetails
                        selectedShipment={selectedShipment}
                        setSelectedDewar={setSelectedDewar}
                        isCreatingShipment={isCreatingShipment}
                        newShipment={newShipment}
                        setNewShipment={setNewShipment}
                        handleSaveShipment={handleSaveShipment}
                        contactPersons={contactPersons}
                        proposals={proposals}
                        returnAddresses={returnAddresses}
                        sx={{ flexGrow: 1 }} // Allow details to grow and take available space
                    />
                )}
            </Grid>
        </Grid>
    );
};

export default ShipmentView;
