export interface ContactPerson {
    id: string;  // ID is a string
    name: string; // Name of the contact person
}

export interface Address {
    id: string; // ID of the address
    address: string; // Full address
}

export interface ReturnAddress {
    id: string; // ID of the return address
    address: string; // Full address
    // Add other fields as necessary
}

export interface Proposal {
    id: number; // ID of the proposal
    number: string; // Proposal number
}

export interface NewShipment {
    shipment_name: string;
    contact_person: string; // Could also be a ContactPerson type if you want to relate it
    proposal_number: string;
    return_address: string; // Could be changed to Address
    comments: string;
}

export interface Dewar {
    id: string; // Add this line
    dewar_name: string;
    tracking_number: string;
    number_of_pucks: number;
    number_of_samples: number;
    return_address: ReturnAddress[];
    contact_person: ContactPerson[];
    status: string;
    ready_date?: string;  // Make sure this is included
    shipping_date?: string;  // Make sure this is included
    arrival_date?: string;  // Make sure this is included
    shippingStatus: string;
    arrivalStatus: string;
    qrcode: string;
}

export interface Shipment {
    shipment_id: string;
    shipment_date: string;
    shipment_name: string;
    number_of_dewars: number;
    shipment_status: string;
    contact_person: ContactPerson[] | null; // Change to an array to accommodate multiple contacts
    proposal_number?: string;
    return_address: Address[]; // Change to an array of Address
    comments?: string;
    dewars: Dewar[];
}

import { DateLocalizer, Event as BigCalendarEvent } from 'react-big-calendar'; // Adjust according to your import structure

export interface CustomEvent extends BigCalendarEvent {
    id: number; // Custom property
    title: string; // Ensure title is included
    start: Date;
    end: Date;
    beamline?: string; // Optional property for beamline
}

export interface Shift {
    beamline: string;
    local_contact: string;
    beamtime_shift: 'morning' | 'evening' | 'night';
}

export interface Beamtime {
    date: string;
    shifts: Shift[];
}